PySAL Release Notes
===================

This is the list of changes to PySAL for each release.

- `PySAL 2.6.0 <https://github.com/pysal/pysal/releases/tag/v2.6.0>`_
- `PySAL 2.5.0 <https://github.com/pysal/pysal/releases/tag/v2.5.0>`_
- `PySAL 2.4.0 <https://github.com/pysal/pysal/releases/tag/v2.4.0>`_
- `PySAL 2.3.0 <https://github.com/pysal/pysal/releases/tag/v2.3.0>`_
- `PySAL 2.2.0 <https://github.com/pysal/pysal/releases/tag/v2.2.0>`_
- `PySAL 2.1.0 <https://github.com/pysal/pysal/releases/tag/v2.1.0>`_
- `PySAL 2.0.0 <https://github.com/pysal/pysal/releases/tag/v2.0.0>`_
- `PySAL 1.14.4 <https://github.com/pysal/pysal/releases/tag/v1.14.4>`_
- `PySAL 1.14.3 <https://github.com/pysal/pysal/releases/tag/v1.14.3>`_
- `PySAL 1.14.2 <https://github.com/pysal/pysal/releases/tag/v1.14.2>`_
- `PySAL 1.13.0 <https://github.com/pysal/pysal/releases/tag/v1.13.0>`_
- `PySAL 1.12.0 <https://github.com/pysal/pysal/releases/tag/v1.12.0>`_
- `PySAL 1.11.2 <https://github.com/pysal/pysal/releases/tag/v1.11.2>`_
- `PySAL 1.11.1 <https://github.com/pysal/pysal/releases/tag/v1.11.1>`_
- `PySAL 1.11.0 <https://github.com/pysal/pysal/releases/tag/v1.11.0>`_
- `PySAL 1.10 <https://github.com/pysal/pysal/releases/tag/v1.10>`_
